class ChatApp {
  constructor() {
    this.username = '';
    this.messages = [];
    this.isDark = false;
    this.particles = [];
    
    this.initElements();
    this.initEventListeners();
    this.initParticles();
    this.loadTheme();
    this.loadMessages();
  }
  
  initElements() {
    this.loginScreen = document.getElementById('loginScreen');
    this.chatScreen = document.getElementById('chatScreen');
    this.usernameInput = document.getElementById('usernameInput');
    this.messageInput = document.getElementById('messageInput');
    this.messageContainer = document.getElementById('messageContainer');
    this.userBadge = document.getElementById('userBadge');
    this.themeToggle = document.getElementById('themeToggle');
    this.particlesContainer = document.getElementById('particles');
  }
  
  initEventListeners() {
    document.getElementById('joinChat').addEventListener('click', () => this.joinChat());
    document.getElementById('sendMessage').addEventListener('click', () => this.sendMessage());
    this.messageInput.addEventListener('keypress', (e) => {
      if (e.key === 'Enter') this.sendMessage();
    });
    this.themeToggle.addEventListener('click', () => this.toggleTheme());
  }
  
  joinChat() {
    const username = this.usernameInput.value.trim();
    if (username.length < 3) {
      alert('Username must be at least 3 characters long');
      return;
    }
    
    this.username = username;
    this.loginScreen.classList.add('hidden');
    this.chatScreen.classList.remove('hidden');
    this.userBadge.textContent = username;
    this.messageInput.focus();
  }
  
  sendMessage() {
    const message = this.messageInput.value.trim();
    if (!message) return;
    
    const messageObj = {
      text: message,
      username: this.username,
      timestamp: new Date().toISOString(),
      id: Date.now()
    };
    
    this.messages.push(messageObj);
    this.saveMessages();
    this.displayMessage(messageObj);
    this.messageInput.value = '';
  }
  
  displayMessage(message) {
    const messageElement = document.createElement('div');
    messageElement.classList.add('message');
    messageElement.classList.add(message.username === this.username ? 'sent' : 'received');
    
    messageElement.innerHTML = `
      <strong>${message.username}</strong>
      <p>${this.escapeHtml(message.text)}</p>
      <small>${new Date(message.timestamp).toLocaleTimeString()}</small>
    `;
    
    this.messageContainer.appendChild(messageElement);
    this.messageContainer.scrollTop = this.messageContainer.scrollHeight;
  }
  
  escapeHtml(unsafe) {
    return unsafe
      .replace(/&/g, "&amp;")
      .replace(/</g, "&lt;")
      .replace(/>/g, "&gt;")
      .replace(/"/g, "&quot;")
      .replace(/'/g, "&#039;");
  }
  
  toggleTheme() {
    this.isDark = !this.isDark;
    document.body.classList.toggle('dark-theme');
    localStorage.setItem('theme', this.isDark ? 'dark' : 'light');
  }
  
  loadTheme() {
    const savedTheme = localStorage.getItem('theme');
    if (savedTheme === 'dark') {
      this.isDark = true;
      document.body.classList.add('dark-theme');
    }
  }
  
  saveMessages() {
    localStorage.setItem('chatMessages', JSON.stringify(this.messages));
  }
  
  loadMessages() {
    const saved = localStorage.getItem('chatMessages');
    if (saved) {
      this.messages = JSON.parse(saved);
      this.messages.forEach(msg => this.displayMessage(msg));
    }
  }
  
  initParticles() {
    const canvas = document.createElement('canvas');
    canvas.style.width = '100%';
    canvas.style.height = '100%';
    this.particlesContainer.appendChild(canvas);
    const ctx = canvas.getContext('2d');
    
    const resize = () => {
      canvas.width = this.particlesContainer.clientWidth;
      canvas.height = this.particlesContainer.clientHeight;
    };
    
    window.addEventListener('resize', resize);
    resize();
    
    for (let i = 0; i < 50; i++) {
      this.particles.push({
        x: Math.random() * canvas.width,
        y: Math.random() * canvas.height,
        size: Math.random() * 3 + 1,
        speedX: Math.random() * 2 - 1,
        speedY: Math.random() * 2 - 1
      });
    }
    
    const animate = () => {
      ctx.clearRect(0, 0, canvas.width, canvas.height);
      
      this.particles.forEach(particle => {
        particle.x += particle.speedX;
        particle.y += particle.speedY;
        
        if (particle.x < 0 || particle.x > canvas.width) particle.speedX *= -1;
        if (particle.y < 0 || particle.y > canvas.height) particle.speedY *= -1;
        
        ctx.beginPath();
        ctx.arc(particle.x, particle.y, particle.size, 0, Math.PI * 2);
        ctx.fillStyle = this.isDark ? '#ffffff22' : '#00000022';
        ctx.fill();
      });
      
      requestAnimationFrame(animate);
    };
    
    animate();
  }
}

document.addEventListener('DOMContentLoaded', () => {
  new ChatApp();
});
